pub struct DamlCreateCommand { /* private fields */ }Expand description
Create a new contract instance based on a template.
Implementations
Sourceimpl DamlCreateCommand
Create a new contract instance based on a template.
impl DamlCreateCommand
Create a new contract instance based on a template.
pub fn new( template_id: impl Into<DamlIdentifier>, create_arguments: impl Into<DamlRecord>, ) -> Self
Sourcepub const fn template_id(&self) -> &DamlIdentifier
pub const fn template_id(&self) -> &DamlIdentifier
The template of contract the client wants to create.
Sourcepub const fn create_arguments(&self) -> &DamlRecord
pub const fn create_arguments(&self) -> &DamlRecord
The arguments required for creating a contract from this template.