pub struct DamlIncompleteAssigned {
pub assigned_event: DamlAssignedEvent,
}Expand description
A contract that was assigned at or before the snapshot offset but
whose matching Unassigned hasn’t been observed yet.
Note: per the proto, this does not mean the contract is active on the target — only that the participant has seen the assign half without the matching unassign half yet.
Fields
assigned_event: DamlAssignedEventTrait Implementations
Sourceimpl Clone for DamlIncompleteAssigned
impl Clone for DamlIncompleteAssigned
Sourcefn clone(&self) -> DamlIncompleteAssigned
fn clone(&self) -> DamlIncompleteAssigned
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DamlIncompleteAssigned
impl Debug for DamlIncompleteAssigned
impl Eq for DamlIncompleteAssigned
Sourceimpl PartialEq for DamlIncompleteAssigned
impl PartialEq for DamlIncompleteAssigned
impl StructuralPartialEq for DamlIncompleteAssigned
Sourceimpl TryFrom<IncompleteAssigned> for DamlIncompleteAssigned
impl TryFrom<IncompleteAssigned> for DamlIncompleteAssigned
Sourcefn try_from(a: IncompleteAssigned) -> DamlResult<Self>
fn try_from(a: IncompleteAssigned) -> DamlResult<Self>
Performs the conversion.